# Generated by Django 4.1.1 on 2023-07-23 09:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('menu', '0007_auto_20230130_1141'),
    ]

    operations = [
        migrations.AddField(
            model_name='menu',
            name='exclude_menu',
            field=models.BooleanField(default=False),
        ),
    ]
